@@ -180,6 +180,12 @@ account_widget_set_control_buttons_sensitivity (EmpathyAccountWidget *self,
       gtk_widget_set_sensitive (priv->apply_button, sensitive);
       gtk_widget_set_sensitive (priv->cancel_button,
           (sensitive || priv->creating_account) && priv->other_accounts_exist);
+
+      if (sensitive)
+        {
+          gtk_widget_set_can_default (priv->apply_button, TRUE);
+          gtk_widget_grab_default (priv->apply_button);
+        }
     }
 }
 
@@ -470,6 +476,16 @@ password_entry_activated_cb (GtkEntry *entry,
         account_widget_apply_and_log_in (self);
 }
 
+static void
+account_entry_activated_cb (GtkEntry *entry,
+    EmpathyAccountWidget *self)
+{
+    EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
+
+    if (gtk_widget_get_sensitive (priv->apply_button))
+        account_widget_apply_and_log_in (self);
+}
+
 void
 empathy_account_widget_setup_widget (EmpathyAccountWidget *self,
     GtkWidget *widget,
@@ -549,6 +565,10 @@ empathy_account_widget_setup_widget (EmpathyAccountWidget *self,
           g_signal_connect (widget, "activate",
               G_CALLBACK (password_entry_activated_cb), self);
         }
+      else if (strstr (param_name, "account"))
+        g_signal_connect (widget, "activate",
+            G_CALLBACK (account_entry_activated_cb), self);
+
 
       g_signal_connect (widget, "changed",
           G_CALLBACK (account_widget_entry_changed_cb), self);
@@ -1420,7 +1440,18 @@ account_widget_build_jabber (EmpathyAccountWidget *self,
         }
       else if (is_facebook)
         {
+          GtkContainer *parent;
+          GList *children;
+
           gtk_widget_hide (label_example_jabber);
+
+          /* Removing the label from list of focusable widgets */
+          parent = GTK_CONTAINER (gtk_widget_get_parent (label_example_fb));
+          children = gtk_container_get_children (parent);
+          children = g_list_remove (children, label_example_fb);
+          gtk_container_set_focus_chain (parent, children);
+          g_list_free (children);
+
           gtk_widget_show (label_example_fb);
           gtk_widget_hide (expander_advanced);
         }
@@ -1922,6 +1953,7 @@ do_constructed (GObject *obj)
   EmpathyAccountWidget *self = EMPATHY_ACCOUNT_WIDGET (obj);
   EmpathyAccountWidgetPriv *priv = GET_PRIV (self);
   TpAccount *account;
+  TpStorageRestrictionFlags storage_restrictions;
   const gchar *display_name, *default_display_name;
   guint i = 0;
   struct {
@@ -1944,9 +1976,13 @@ do_constructed (GObject *obj)
 
   account = empathy_account_settings_get_account (priv->settings);
 
+  if (account != NULL)
+    storage_restrictions = tp_account_get_storage_restrictions (account);
+  else
+    storage_restrictions = 0;
+
   /* Empathy can only edit accounts without the Cannot_Set_Parameters flag */
-  if (tp_account_get_storage_restrictions (account) &
-      TP_STORAGE_RESTRICTION_FLAG_CANNOT_SET_PARAMETERS)
+  if (storage_restrictions & TP_STORAGE_RESTRICTION_FLAG_CANNOT_SET_PARAMETERS)
     {
       DEBUG ("Account is provided by an external storage provider");
 
@@ -2005,7 +2041,7 @@ do_constructed (GObject *obj)
 
   /* handle apply and cancel button */
   if (!priv->simple &&
-      !(tp_account_get_storage_restrictions (account) &
+      !(storage_restrictions &
         TP_STORAGE_RESTRICTION_FLAG_CANNOT_SET_PARAMETERS))
     {
       GtkWidget *hbox = gtk_hbox_new (TRUE, 3);
@@ -2066,8 +2102,7 @@ do_constructed (GObject *obj)
 #endif /* HAVE_MEEGO */
 
   /* add the Enable checkbox to accounts that support it */
-  if (!(tp_account_get_storage_restrictions (account) &
-      TP_STORAGE_RESTRICTION_FLAG_CANNOT_SET_ENABLED))
+  if (!(storage_restrictions & TP_STORAGE_RESTRICTION_FLAG_CANNOT_SET_ENABLED))
     add_enable_checkbox (self, account);
 
   /* hook up to widget destruction to unref ourselves */
