@@ -29,6 +29,7 @@
 G_BEGIN_DECLS
 
 void empathy_subscription_dialog_show        (EmpathyContact *contact,
+				              const gchar *message,
 				              GtkWindow      *parent);
 void empathy_contact_information_dialog_show (EmpathyContact *contact,
 					      GtkWindow      *parent);
@@ -38,9 +39,6 @@ void empathy_contact_personal_dialog_show    (GtkWindow      *parent);
 void empathy_new_contact_dialog_show         (GtkWindow     *parent);
 void empathy_new_contact_dialog_show_with_contact (GtkWindow     *parent,
                                                    EmpathyContact *contact);
-gboolean empathy_block_contact_dialog_show (GtkWindow      *parent,
-					    EmpathyContact *contact,
-					    gboolean       *abusive);
 
 G_END_DECLS
 
