@@ -81,6 +81,12 @@ typedef struct
   guint expand_groups_idle_handler;
   /* owned string (group name) -> bool (whether to expand/contract) */
   GHashTable *expand_groups;
+
+  /* Auto scroll */
+  guint auto_scroll_timeout_id;
+  /* Distance between mouse pointer and the nearby border. Negative when
+     scrolling updards.*/
+  gint distance;
 } EmpathyIndividualViewPriv;
 
 typedef struct
@@ -208,7 +214,8 @@ individual_view_query_tooltip_cb (EmpathyIndividualView *view,
     {
       priv->tooltip_widget = empathy_individual_widget_new (individual,
           EMPATHY_INDIVIDUAL_WIDGET_FOR_TOOLTIP |
-          EMPATHY_INDIVIDUAL_WIDGET_SHOW_LOCATION);
+          EMPATHY_INDIVIDUAL_WIDGET_SHOW_LOCATION |
+          EMPATHY_INDIVIDUAL_WIDGET_SHOW_CLIENT_TYPES);
       gtk_container_set_border_width (GTK_CONTAINER (priv->tooltip_widget), 8);
       g_object_ref (priv->tooltip_widget);
       g_signal_connect (priv->tooltip_widget, "destroy",
@@ -549,6 +556,34 @@ individual_view_drag_motion_cb (DragMotionData *data)
   return FALSE;
 }
 
+/* Minimum distance between the mouse pointer and a horizontal border when we
+   start auto scrolling. */
+#define AUTO_SCROLL_MARGIN_SIZE 20
+/* How far to scroll per one tick. */
+#define AUTO_SCROLL_PITCH       10
+
+static gboolean
+individual_view_auto_scroll_cb (EmpathyIndividualView *self)
+{
+	EmpathyIndividualViewPriv *priv = GET_PRIV (self);
+	GtkAdjustment         *adj;
+	gdouble                new_value;
+
+	adj = gtk_scrollable_get_vadjustment (GTK_SCROLLABLE (self));
+
+	if (priv->distance < 0)
+		new_value = gtk_adjustment_get_value (adj) - AUTO_SCROLL_PITCH;
+	else
+		new_value = gtk_adjustment_get_value (adj) + AUTO_SCROLL_PITCH;
+
+	new_value = CLAMP (new_value, gtk_adjustment_get_lower (adj),
+		gtk_adjustment_get_upper (adj) - gtk_adjustment_get_page_size (adj));
+
+	gtk_adjustment_set_value (adj, new_value);
+
+	return TRUE;
+}
+
 static gboolean
 individual_view_drag_motion (GtkWidget *widget,
     GdkDragContext *context,
@@ -566,10 +601,32 @@ individual_view_drag_motion (GtkWidget *widget,
   gboolean is_different = FALSE;
   gboolean cleanup = TRUE;
   gboolean retval = TRUE;
+  GtkAllocation allocation;
 
   priv = GET_PRIV (EMPATHY_INDIVIDUAL_VIEW (widget));
   model = gtk_tree_view_get_model (GTK_TREE_VIEW (widget));
 
+
+  if (priv->auto_scroll_timeout_id != 0)
+    {
+      g_source_remove (priv->auto_scroll_timeout_id);
+      priv->auto_scroll_timeout_id = 0;
+    }
+
+  gtk_widget_get_allocation (widget, &allocation);
+
+  if (y < AUTO_SCROLL_MARGIN_SIZE ||
+      y > (allocation.height - AUTO_SCROLL_MARGIN_SIZE))
+    {
+      if (y < AUTO_SCROLL_MARGIN_SIZE)
+        priv->distance = MIN (-y, -1);
+      else
+        priv->distance = MAX (allocation.height - y, 1);
+
+      priv->auto_scroll_timeout_id = g_timeout_add (10 * ABS (priv->distance),
+          (GSourceFunc) individual_view_auto_scroll_cb, widget);
+    }
+
   is_row = gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (widget),
       x, y, &path, NULL, NULL, NULL);
 
@@ -624,7 +681,7 @@ individual_view_drag_motion (GtkWidget *widget,
         }
 
       if (individual != NULL &&
-          folks_individual_is_online (individual) &&
+          folks_presence_is_online (FOLKS_PRESENCE (individual)) &&
           (caps & EMPATHY_CAPABILITIES_FT))
         {
           gdk_drag_status (context, GDK_ACTION_COPY, time_);
@@ -1609,7 +1666,7 @@ individual_view_is_visible_individual (EmpathyIndividualView *self,
     return (priv->show_offline || is_online);
 
   /* check alias name */
-  str = folks_individual_get_alias (individual);
+  str = folks_aliasable_get_alias (FOLKS_ALIASABLE (individual));
 
   if (empathy_live_search_match (live, str))
     return TRUE;
@@ -1776,6 +1833,8 @@ individual_view_constructed (GObject *object)
       "is_group", EMPATHY_INDIVIDUAL_STORE_COL_IS_GROUP);
   gtk_tree_view_column_add_attribute (col, cell,
       "compact", EMPATHY_INDIVIDUAL_STORE_COL_COMPACT);
+  gtk_tree_view_column_add_attribute (col, cell,
+      "client-types", EMPATHY_INDIVIDUAL_STORE_COL_CLIENT_TYPES);
 
   /* Audio Call Icon */
   cell = empathy_cell_renderer_activatable_new ();
@@ -2129,8 +2188,8 @@ empathy_individual_view_dup_selected (EmpathyIndividualView *view)
   return individual;
 }
 
-gchar *
-empathy_individual_view_get_selected_group (EmpathyIndividualView *view,
+static gchar *
+empathy_individual_view_dup_selected_group (EmpathyIndividualView *view,
     gboolean *is_fake_group)
 {
   EmpathyIndividualViewPriv *priv;
@@ -2196,7 +2255,7 @@ individual_view_group_remove_activate_cb (GtkMenuItem *menuitem,
 {
   gchar *group;
 
-  group = empathy_individual_view_get_selected_group (view, NULL);
+  group = empathy_individual_view_dup_selected_group (view, NULL);
   if (group != NULL)
     {
       gchar *text;
@@ -2237,10 +2296,11 @@ empathy_individual_view_get_group_menu (EmpathyIndividualView *view)
               EMPATHY_INDIVIDUAL_VIEW_FEATURE_GROUPS_REMOVE)))
     return NULL;
 
-  group = empathy_individual_view_get_selected_group (view, &is_fake_group);
+  group = empathy_individual_view_dup_selected_group (view, &is_fake_group);
   if (!group || is_fake_group)
     {
       /* We can't alter fake groups */
+      g_free (group);
       return NULL;
     }
 
@@ -2292,7 +2352,7 @@ individual_view_remove_activate_cb (GtkMenuItem *menuitem,
       text =
           g_strdup_printf (_
           ("Do you really want to remove the contact '%s'?"),
-          folks_individual_get_alias (individual));
+          folks_aliasable_get_alias (FOLKS_ALIASABLE (individual)));
       if (individual_view_remove_dialog_show (parent, _("Removing contact"),
               text))
         {
