@@ -30,13 +30,10 @@
 #include <telepathy-glib/util.h>
 
 #include <folks/folks.h>
-#include <folks/folks-telepathy.h>
 
 #include <extensions/extensions.h>
 
 #include "empathy-individual-manager.h"
-#include "empathy-contact-manager.h"
-#include "empathy-contact-list.h"
 #include "empathy-marshal.h"
 #include "empathy-utils.h"
 
@@ -52,7 +49,6 @@
 typedef struct
 {
   FolksIndividualAggregator *aggregator;
-  EmpathyContactManager *contact_manager;
   GHashTable *individuals; /* Individual.id -> Individual */
 } EmpathyIndividualManagerPriv;
 
@@ -86,8 +82,8 @@ individual_notify_is_favourite_cb (FolksIndividual *individual,
     GParamSpec *pspec,
     EmpathyIndividualManager *self)
 {
-  gboolean is_favourite = folks_favouritable_get_is_favourite (
-      FOLKS_FAVOURITABLE (individual));
+  gboolean is_favourite = folks_favourite_get_is_favourite (
+      FOLKS_FAVOURITE (individual));
   g_signal_emit (self, signals[FAVOURITES_CHANGED], 0, individual,
       is_favourite);
 }
@@ -223,7 +219,6 @@ individual_manager_dispose (GObject *object)
   EmpathyIndividualManagerPriv *priv = GET_PRIV (object);
 
   g_hash_table_destroy (priv->individuals);
-  tp_clear_object (&priv->contact_manager);
   tp_clear_object (&priv->aggregator);
 
   G_OBJECT_CLASS (empathy_individual_manager_parent_class)->dispose (object);
@@ -317,7 +312,6 @@ empathy_individual_manager_init (EmpathyIndividualManager *self)
       EMPATHY_TYPE_INDIVIDUAL_MANAGER, EmpathyIndividualManagerPriv);
 
   self->priv = priv;
-  priv->contact_manager = empathy_contact_manager_dup_singleton ();
   priv->individuals = g_hash_table_new_full (g_str_hash, g_str_equal,
       NULL, g_object_unref);
 
@@ -389,10 +383,7 @@ empathy_individual_manager_add_from_contact (EmpathyIndividualManager *self,
     EmpathyContact *contact)
 {
   EmpathyIndividualManagerPriv *priv;
-  FolksBackendStore *backend_store;
-  FolksBackend *backend;
-  FolksPersonaStore *persona_store;
-  GHashTable* details, *persona_stores;
+  GHashTable* details;
   TpAccount *account;
   const gchar *store_id;
 
@@ -411,41 +402,15 @@ empathy_individual_manager_add_from_contact (EmpathyIndividualManager *self,
   account = empathy_contact_get_account (contact);
   store_id = tp_proxy_get_object_path (TP_PROXY (account));
 
-  /* Get the persona store to use */
-  backend_store = folks_backend_store_dup ();
-  backend =
-      folks_backend_store_dup_backend_by_name (backend_store, "telepathy");
-
-  if (backend == NULL)
-    {
-      g_warning ("Failed to add individual from contact: couldn't get "
-          "'telepathy' backend");
-      goto finish;
-    }
-
-  persona_stores = folks_backend_get_persona_stores (backend);
-  persona_store = g_hash_table_lookup (persona_stores, store_id);
-
-  if (persona_store == NULL)
-    {
-      g_warning ("Failed to add individual from contact: couldn't get persona "
-          "store '%s'", store_id);
-      goto finish;
-    }
-
   details = tp_asv_new (
       "contact", G_TYPE_STRING, empathy_contact_get_id (contact),
       NULL);
 
   folks_individual_aggregator_add_persona_from_details (
-      priv->aggregator, NULL, persona_store, details,
+      priv->aggregator, NULL, "telepathy", store_id, details,
       aggregator_add_persona_from_details_cb, contact);
 
   g_hash_table_destroy (details);
-
-finish:
-  tp_clear_object (&backend);
-  tp_clear_object (&backend_store);
 }
 
 static void
@@ -489,80 +454,6 @@ empathy_individual_manager_remove (EmpathyIndividualManager *self,
       aggregator_remove_individual_cb, self);
 }
 
-/**
- * empathy_individual_manager_supports_blocking
- * @self: the #EmpathyIndividualManager
- * @individual: an individual to check
- *
- * Indicates whether any personas of an @individual can be blocked.
- *
- * Returns: %TRUE if any persona supports contact blocking
- */
-gboolean
-empathy_individual_manager_supports_blocking (EmpathyIndividualManager *self,
-    FolksIndividual *individual)
-{
-  EmpathyIndividualManagerPriv *priv;
-  GList *personas, *l;
-
-  g_return_val_if_fail (EMPATHY_IS_INDIVIDUAL_MANAGER (self), FALSE);
-
-  priv = GET_PRIV (self);
-
-  personas = folks_individual_get_personas (individual);
-
-  for (l = personas; l != NULL; l = l->next)
-    {
-      TpfPersona *persona = l->data;
-      TpConnection *conn;
-
-      if (!TPF_IS_PERSONA (persona))
-        continue;
-
-      conn = tp_contact_get_connection (tpf_persona_get_contact (persona));
-
-      if (empathy_individual_manager_get_flags_for_connection (self, conn) &
-          EMPATHY_INDIVIDUAL_MANAGER_CAN_BLOCK)
-        return TRUE;
-    }
-
-  return FALSE;
-}
-
-void
-empathy_individual_manager_set_blocked (EmpathyIndividualManager *self,
-    FolksIndividual *individual,
-    gboolean blocked,
-    gboolean abusive)
-{
-  EmpathyIndividualManagerPriv *priv;
-  GList *personas, *l;
-
-  g_return_if_fail (EMPATHY_IS_INDIVIDUAL_MANAGER (self));
-
-  priv = GET_PRIV (self);
-
-  personas = folks_individual_get_personas (individual);
-
-  for (l = personas; l != NULL; l = l->next)
-    {
-      TpfPersona *persona = l->data;
-      EmpathyContact *contact;
-
-      if (!TPF_IS_PERSONA (persona))
-        continue;
-
-      contact = empathy_contact_dup_from_tp_contact (
-          tpf_persona_get_contact (persona));
-      empathy_contact_set_persona (contact, FOLKS_PERSONA (persona));
-      empathy_contact_list_set_blocked (
-          EMPATHY_CONTACT_LIST (priv->contact_manager),
-          contact, blocked, abusive);
-
-      g_object_unref (contact);
-    }
-}
-
 static void
 groups_change_group_cb (GObject *source,
     GAsyncResult *result,
@@ -606,40 +497,6 @@ empathy_individual_manager_remove_group (EmpathyIndividualManager *manager,
       (gpointer) group);
 }
 
-EmpathyIndividualManagerFlags
-empathy_individual_manager_get_flags_for_connection (
-    EmpathyIndividualManager *self,
-    TpConnection *connection)
-{
-  EmpathyIndividualManagerPriv *priv;
-  EmpathyContactListFlags list_flags;
-  EmpathyIndividualManagerFlags flags;
-
-  g_return_val_if_fail (EMPATHY_IS_INDIVIDUAL_MANAGER (self),
-      EMPATHY_INDIVIDUAL_MANAGER_NO_FLAGS);
-
-  priv = GET_PRIV (self);
-
-  list_flags = empathy_contact_manager_get_flags_for_connection (
-    priv->contact_manager, connection);
-
-  flags = EMPATHY_INDIVIDUAL_MANAGER_NO_FLAGS;
-  if (list_flags & EMPATHY_CONTACT_LIST_CAN_ADD)
-    flags |= EMPATHY_INDIVIDUAL_MANAGER_CAN_ADD;
-  if (list_flags & EMPATHY_CONTACT_LIST_CAN_REMOVE)
-    flags |= EMPATHY_INDIVIDUAL_MANAGER_CAN_REMOVE;
-  if (list_flags & EMPATHY_CONTACT_LIST_CAN_ALIAS)
-    flags |= EMPATHY_INDIVIDUAL_MANAGER_CAN_ALIAS;
-  if (list_flags & EMPATHY_CONTACT_LIST_CAN_GROUP)
-    flags |= EMPATHY_INDIVIDUAL_MANAGER_CAN_GROUP;
-  if (list_flags & EMPATHY_CONTACT_LIST_CAN_BLOCK)
-    flags |= EMPATHY_INDIVIDUAL_MANAGER_CAN_BLOCK;
-  if (list_flags & EMPATHY_CONTACT_LIST_CAN_REPORT_ABUSIVE)
-    flags |= EMPATHY_INDIVIDUAL_MANAGER_CAN_REPORT_ABUSIVE;
-
-  return flags;
-}
-
 static void
 link_personas_cb (FolksIndividualAggregator *aggregator,
     GAsyncResult *async_result,
