@@ -111,6 +111,10 @@ typedef struct {
 
 	/* Last user action time we acted upon to show a tab */
 	guint32    x_user_action_time;
+
+	GSettings *gsettings_chat;
+	GSettings *gsettings_notif;
+	GSettings *gsettings_ui;
 } EmpathyChatWindowPriv;
 
 static GList *chat_windows = NULL;
@@ -533,9 +537,7 @@ chat_window_icon_update (EmpathyChatWindowPriv *priv)
 		gtk_window_set_icon_name (GTK_WINDOW (priv->dialog),
 					  EMPATHY_IMAGE_MESSAGE);
 	} else {
-		GSettings *gsettings = g_settings_new (EMPATHY_PREFS_CHAT_SCHEMA);
-
-		avatar_in_icon = g_settings_get_boolean (gsettings,
+		avatar_in_icon = g_settings_get_boolean (priv->gsettings_chat,
 				EMPATHY_PREFS_CHAT_AVATAR_IN_ICON);
 
 		if (n_chats == 1 && avatar_in_icon) {
@@ -549,8 +551,6 @@ chat_window_icon_update (EmpathyChatWindowPriv *priv)
 		} else {
 			gtk_window_set_icon_name (GTK_WINDOW (priv->dialog), NULL);
 		}
-
-		g_object_unref (gsettings);
 	}
 }
 
@@ -1287,14 +1287,9 @@ chat_window_show_or_update_notification (EmpathyChatWindow *window,
 	if (!empathy_notify_manager_notification_is_enabled (priv->notify_mgr)) {
 		return;
 	} else {
-		GSettings *gsettings = g_settings_new (
-				EMPATHY_PREFS_NOTIFICATIONS_SCHEMA);
-
-		res = g_settings_get_boolean (gsettings,
+		res = g_settings_get_boolean (priv->gsettings_notif,
 				EMPATHY_PREFS_NOTIFICATIONS_FOCUS);
 
-		g_object_unref (gsettings);
-
 		if (!res) {
 			return;
 		}
@@ -1875,6 +1870,9 @@ chat_window_finalize (GObject *object)
 	g_object_unref (priv->ui_manager);
 	g_object_unref (priv->chatroom_manager);
 	g_object_unref (priv->notify_mgr);
+	g_object_unref (priv->gsettings_chat);
+	g_object_unref (priv->gsettings_notif);
+	g_object_unref (priv->gsettings_ui);
 
 	if (priv->notification != NULL) {
 		notify_notification_close (priv->notification, NULL);
@@ -1985,6 +1983,9 @@ empathy_chat_window_init (EmpathyChatWindow *window)
 	g_object_ref (priv->ui_manager);
 	g_object_unref (gui);
 
+	priv->gsettings_chat = g_settings_new (EMPATHY_PREFS_CHAT_SCHEMA);
+	priv->gsettings_notif = g_settings_new (EMPATHY_PREFS_NOTIFICATIONS_SCHEMA);
+	priv->gsettings_ui = g_settings_new (EMPATHY_PREFS_UI_SCHEMA);
 	priv->chatroom_manager = empathy_chatroom_manager_dup_singleton (NULL);
 
 	priv->notebook = gtk_notebook_new ();
@@ -2182,15 +2183,12 @@ empathy_chat_window_add_chat (EmpathyChatWindow *window,
 
 	/* If this window has just been created, position it */
 	if (priv->chats == NULL) {
-		GSettings *gsettings = g_settings_new (EMPATHY_PREFS_UI_SCHEMA);
 		const gchar *name = "chat-window";
 		gboolean     separate_windows;
 
-		separate_windows = g_settings_get_boolean (gsettings,
+		separate_windows = g_settings_get_boolean (priv->gsettings_ui,
 				EMPATHY_PREFS_UI_SEPARATE_CHAT_WINDOWS);
 
-		g_object_unref (gsettings);
-
 		if (empathy_chat_is_room (chat))
 			name = "room-window";
 
