@@ -82,6 +82,9 @@ typedef struct {
   GSList *approvals;
 
   gint ringing;
+
+  GSettings *gsettings_notif;
+  GSettings *gsettings_ui;
 } EmpathyEventManagerPriv;
 
 typedef struct _EventPriv EventPriv;
@@ -150,8 +153,6 @@ event_manager_approval_free (EventManagerApproval *approval)
   g_slice_free (EventManagerApproval, approval);
 }
 
-static void event_remove (EventPriv *event);
-
 static void
 event_free (EventPriv *event)
 {
@@ -182,6 +183,14 @@ event_remove (EventPriv *event)
   event_free (event);
 }
 
+void
+empathy_event_remove (EmpathyEvent *event_public)
+{
+  EventPriv *event = (EventPriv *) event_public;
+
+  event_remove (event);
+}
+
 static gboolean
 autoremove_event_timeout_cb (EventPriv *event)
 {
@@ -191,19 +200,12 @@ autoremove_event_timeout_cb (EventPriv *event)
 }
 
 static gboolean
-display_notify_area (void)
-
+display_notify_area (EmpathyEventManager *self)
 {
-  GSettings *gsettings;
-  gboolean result;
+  EmpathyEventManagerPriv *priv = GET_PRIV (self);
 
-  gsettings = g_settings_new (EMPATHY_PREFS_UI_SCHEMA);
-
-  result = g_settings_get_boolean (gsettings,
+  return g_settings_get_boolean (priv->gsettings_ui,
       EMPATHY_PREFS_UI_EVENTS_NOTIFY_AREA);
-  g_object_unref (gsettings);
-
-  return result;
 }
 
 static void
@@ -236,7 +238,7 @@ event_manager_add (EmpathyEventManager *manager,
   DEBUG ("Adding event %p", event);
   priv->events = g_slist_prepend (priv->events, event);
 
-  if (!display_notify_area ())
+  if (!display_notify_area (manager))
     {
       /* Don't fire the 'event-added' signal as we activate the event now */
       if (approval != NULL)
@@ -970,7 +972,8 @@ out:
 static void
 event_pending_subscribe_func (EventPriv *event)
 {
-  empathy_subscription_dialog_show (event->public.contact, NULL);
+  empathy_subscription_dialog_show (event->public.contact, event->public.header,
+      NULL);
   event_remove (event);
 }
 
@@ -1025,10 +1028,10 @@ event_manager_presence_changed_cb (EmpathyContact *contact,
     TpConnectionPresenceType previous,
     EmpathyEventManager *manager)
 {
+  EmpathyEventManagerPriv *priv = GET_PRIV (manager);
   TpAccount *account;
   gchar *header = NULL;
   EmpathyIdle *idle;
-  GSettings *gsettings = g_settings_new (EMPATHY_PREFS_NOTIFICATIONS_SCHEMA);
   GtkWidget *window = empathy_main_window_dup ();
 
   account = empathy_contact_get_account (contact);
@@ -1047,7 +1050,7 @@ event_manager_presence_changed_cb (EmpathyContact *contact,
           /* someone is logging off */
           empathy_sound_play (window, EMPATHY_SOUND_CONTACT_DISCONNECTED);
 
-          if (g_settings_get_boolean (gsettings,
+          if (g_settings_get_boolean (priv->gsettings_notif,
                 EMPATHY_PREFS_NOTIFICATIONS_CONTACT_SIGNOUT))
             {
               header = g_strdup_printf (_("%s is now offline."),
@@ -1067,7 +1070,7 @@ event_manager_presence_changed_cb (EmpathyContact *contact,
           /* someone is logging in */
           empathy_sound_play (window, EMPATHY_SOUND_CONTACT_CONNECTED);
 
-          if (g_settings_get_boolean (gsettings,
+          if (g_settings_get_boolean (priv->gsettings_notif,
                 EMPATHY_PREFS_NOTIFICATIONS_CONTACT_SIGNIN))
             {
               header = g_strdup_printf (_("%s is now online."),
@@ -1082,7 +1085,6 @@ event_manager_presence_changed_cb (EmpathyContact *contact,
 
 out:
   g_object_unref (idle);
-  g_object_unref (gsettings);
   g_object_unref (window);
 }
 
@@ -1137,6 +1139,8 @@ event_manager_finalize (GObject *object)
   g_slist_free (priv->approvals);
   g_object_unref (priv->contact_manager);
   g_object_unref (priv->approver);
+  g_object_unref (priv->gsettings_notif);
+  g_object_unref (priv->gsettings_ui);
 }
 
 static void
@@ -1189,6 +1193,9 @@ empathy_event_manager_init (EmpathyEventManager *manager)
 
   manager->priv = priv;
 
+  priv->gsettings_notif = g_settings_new (EMPATHY_PREFS_NOTIFICATIONS_SCHEMA);
+  priv->gsettings_ui = g_settings_new (EMPATHY_PREFS_UI_SCHEMA);
+
   priv->contact_manager = empathy_contact_manager_dup_singleton ();
   g_signal_connect (priv->contact_manager, "pendings-changed",
     G_CALLBACK (event_manager_pendings_changed_cb), manager);
