@@ -51,16 +51,13 @@ struct _EmpathyEventManagerClass {
 typedef enum {
     EMPATHY_EVENT_TYPE_CHAT,
     EMPATHY_EVENT_TYPE_VOIP,
-    EMPATHY_EVENT_TYPE_CALL,
     EMPATHY_EVENT_TYPE_TRANSFER,
     EMPATHY_EVENT_TYPE_SUBSCRIPTION,
     EMPATHY_EVENT_TYPE_PRESENCE,
     EMPATHY_EVENT_TYPE_INVITATION,
-    EMPATHY_EVENT_TYPE_AUTH,
 } EmpathyEventType;
 
 typedef struct {
-    TpAccount *account;
     EmpathyContact *contact;
     EmpathyEventType type;
     gchar *icon_name;
@@ -77,6 +74,7 @@ void                 empathy_event_activate              (EmpathyEvent        *e
 void                 empathy_event_inhibit_updates       (EmpathyEvent        *event);
 void                 empathy_event_approve               (EmpathyEvent        *event);
 void                 empathy_event_decline               (EmpathyEvent        *event);
+void                 empathy_event_remove                (EmpathyEvent        *event);
 
 G_END_DECLS
 
